1.0.0 API documentation: matrix_transform_2d.hpp File Reference

| 1.0.0 API documentation

Functions
matrix_transform_2d.hpp File Reference

GLM_GTX_matrix_transform_2d More...

Go to the source code of this file.

## Functions
template<typename T , qualifier Q>
GLM_FUNC_QUALIFIER mat< 3, 3, T, Q > | rotate (mat< 3, 3, T, Q > const &m, T angle)
| Builds a rotation 3 * 3 matrix created from an angle. More...
template<typename T , qualifier Q>
GLM_FUNC_QUALIFIER mat< 3, 3, T, Q > | scale (mat< 3, 3, T, Q > const &m, vec< 2, T, Q > const &v)
| Builds a scale 3 * 3 matrix created from a vector of 2 components. More...
template<typename T , qualifier Q>
GLM_FUNC_QUALIFIER mat< 3, 3, T, Q > | shearX (mat< 3, 3, T, Q > const &m, T y)
| Builds an horizontal (parallel to the x axis) shear 3 * 3 matrix. More...
template<typename T , qualifier Q>
GLM_FUNC_QUALIFIER mat< 3, 3, T, Q > | shearY (mat< 3, 3, T, Q > const &m, T x)
| Builds a vertical (parallel to the y axis) shear 3 * 3 matrix. More...
template<typename T , qualifier Q>
GLM_FUNC_QUALIFIER mat< 3, 3, T, Q > | translate (mat< 3, 3, T, Q > const &m, vec< 2, T, Q > const &v)
| Builds a translation 3 * 3 matrix created from a vector of 2 components. More...

## Detailed Description

GLM_GTX_matrix_transform_2d

Author
  Miguel Ángel Pérez Martínez

See also
  Core features (dependence)

Definition in file matrix_transform_2d.hpp.